@@ -1,7 +1,7 @@
 package command
 
 import (
-	"errors"
+	"fmt"
 	"io"
 	"os/exec"
 	"strings"
@@ -16,31 +16,31 @@ func Output(cmd *exec.Cmd, stream string) (string, error) {
 	case "stdout":
 		pipe, err = cmd.StdoutPipe()
 		if err != nil {
-			return "", errors.Join(errors.New("stdout pipe"), err)
+			return "", fmt.Errorf("stdout pipe: %w", err)
 		}
 		defer pipe.Close()
 	case "stderr":
 		pipe, err = cmd.StderrPipe()
 		if err != nil {
-			return "", errors.Join(errors.New("stderr pipe"), err)
+			return "", fmt.Errorf("stderr pipe: %w", err)
 		}
 		defer pipe.Close()
 	case "combined":
 		output, err = cmd.CombinedOutput()
 		if err != nil {
-			return "", errors.Join(errors.New("combined output"), err)
+			return "", fmt.Errorf("combined output: %w", err)
 		}
 	}
 
 	// This means it's not combined output
 	if len(output) == 0 {
 		if err := cmd.Start(); err != nil {
-			return "", errors.Join(errors.New("starting command"), err)
+			return "", fmt.Errorf("starting command: %w", err)
 		}
 
 		output, err = io.ReadAll(pipe)
 		if err != nil {
-			return "", errors.Join(errors.New("read output"), err)
+			return "", fmt.Errorf("read output: %w", err)
 		}
 	}
 	return strings.TrimSpace(string(output)), nil
