@@ -9,7 +9,9 @@ import (
 
 func (r *FSOCmd) Run(ctx *types.Context) error {
 	if r.Age.Name != "" {
-		return runAge(ctx, r.Age.Name, r.Age.Op, r.Age.Val, r.Age.Unit)
+		success, err := runAge(ctx, r.Age.Name, r.Age.Op, r.Age.Val, r.Age.Unit)
+		ctx.Success = success
+		return err
 	}
 	return errors.New("unimplemented command")
 }
