@@ -9,11 +9,13 @@ import (
 	"os"
 	"regexp"
 	"runtime"
+	"sort"
 	"strings"
 
 	"github.com/charmbracelet/lipgloss"
 	"github.com/charmbracelet/lipgloss/table"
 	"github.com/oalders/is/attr"
+	"github.com/oalders/is/audio"
 	"github.com/oalders/is/battery"
 	is_os "github.com/oalders/is/os"
 	"github.com/oalders/is/parser"
@@ -21,6 +23,13 @@ import (
 	"github.com/oalders/is/version"
 )
 
+const (
+	manpath  = "MANPATH"
+	path     = "PATH"
+	trueStr  = "true"
+	falseStr = "false"
+)
+
 // Run "is known ...".
 //
 //nolint:cyclop
@@ -31,11 +40,31 @@ func (r *KnownCmd) Run(ctx *types.Context) error {
 
 		switch {
 		case r.Summary.Attr != "":
-			return summary(ctx, r.Summary.Attr, r.Summary.Nth, r.Summary.JSON)
+			return summary(ctx, r.Summary.Attr, r.Summary.Nth, r.Summary.JSON, r.Summary.MD)
 		case r.OS.Attr != "":
 			result, err = is_os.Info(ctx, r.OS.Attr)
 		case r.CLI.Attr != "":
 			result, err = runCLI(ctx, r.CLI.Name)
+		case r.Var.Name != "":
+			result, err = getEnv(ctx, r.Var.Name, r.Var.JSON)
+		case r.Audio.Attr != "":
+			if r.Audio.Attr == "level" { //nolint:nestif
+				level, levelErr := audio.Level()
+				if levelErr != nil {
+					return levelErr
+				}
+				result = fmt.Sprintf("%d", level)
+			} else {
+				muted, mutedErr := audio.IsMuted()
+				if mutedErr != nil {
+					return mutedErr
+				}
+				if muted {
+					result = trueStr
+				} else {
+					result = falseStr
+				}
+			}
 		case r.Battery.Attr != "":
 			result, err = battery.GetAttrAsString(
 				ctx,
@@ -68,7 +97,7 @@ func (r *KnownCmd) Run(ctx *types.Context) error {
 		}
 	}
 
-	if result != "" {
+	if r.Var.Name == "" && result != "" {
 		ctx.Success = true
 	}
 
@@ -116,7 +145,10 @@ func runCLI(ctx *types.Context, cliName string) (string, error) {
 	return result, err
 }
 
-func tabular(headers []string, rows [][]string) string {
+func tabular(headers []string, rows [][]string, asMarkdown bool) string {
+	if asMarkdown {
+		return markdown(headers, rows)
+	}
 	renderer := lipgloss.NewRenderer(os.Stdout)
 
 	return table.New().
@@ -124,22 +156,53 @@ func tabular(headers []string, rows [][]string) string {
 		Rows(rows...).
 		Border(lipgloss.ThickBorder()).
 		BorderStyle(renderer.NewStyle().Foreground(lipgloss.Color("238"))).
+		BorderRow(true).
 		StyleFunc(func(_, _ int) lipgloss.Style {
 			return renderer.NewStyle().Padding(0, 1)
 		}).String()
 }
 
+func markdown(headers []string, rows [][]string) string {
+	var buf strings.Builder
+
+	// Header row.
+	buf.WriteString("| " + strings.Join(headers, " | ") + " |\n")
+
+	// Separator row.
+	buf.WriteString("|")
+	for range headers {
+		buf.WriteString("---|")
+	}
+	buf.WriteString("\n")
+
+	// Data rows.
+	for _, row := range rows {
+		row[1] = strings.ReplaceAll(row[1], "\n", "<br>")
+		buf.WriteString("| " + strings.Join(row, " | ") + " |\n")
+	}
+
+	return buf.String()
+}
+
 func success(ctx *types.Context, msg string) {
 	fmt.Println(msg) //nolint:forbidigo
 	ctx.Success = true
 }
 
-func summary(ctx *types.Context, attr string, nth int, asJSON bool) error {
+func summary(ctx *types.Context, attr string, nth int, asJSON bool, asMarkdown bool) error {
 	if attr == "os" {
-		return osSummary(ctx, asJSON)
+		return osSummary(ctx, asJSON, asMarkdown)
 	}
 	if attr == "battery" {
-		return batterySummary(ctx, nth, asJSON)
+		batt, err := batterySummary(ctx, nth, asJSON, asMarkdown)
+		if err != nil {
+			return err
+		}
+		success(ctx, batt)
+		return nil
+	}
+	if attr == "var" {
+		return envSummary(ctx, asJSON, asMarkdown)
 	}
 	return fmt.Errorf("unknown attribute: %s", attr)
 }
@@ -153,7 +216,7 @@ func toJSON(record any) (string, error) {
 	return string(data), nil
 }
 
-func osSummary(ctx *types.Context, asJSON bool) error {
+func osSummary(ctx *types.Context, asJSON bool, asMarkdown bool) error {
 	summary, err := is_os.ReleaseSummary(ctx)
 	if err != nil {
 		return err
@@ -174,9 +237,11 @@ func osSummary(ctx *types.Context, asJSON bool) error {
 	rows := [][]string{
 		{"name", summary.Name},
 		{"version", summary.Version},
-		{"version-codename", summary.VersionCodeName},
 	}
 
+	if summary.VersionCodeName != "" {
+		rows = append(rows, []string{"version-codename", summary.VersionCodeName})
+	}
 	if summary.ID != "" {
 		rows = append(rows, []string{"id", summary.ID})
 	}
@@ -186,30 +251,28 @@ func osSummary(ctx *types.Context, asJSON bool) error {
 	if summary.PrettyName != "" {
 		rows = append(rows, []string{"pretty-name", summary.PrettyName})
 	}
-	success(ctx, tabular(headers, rows))
+	success(ctx, tabular(headers, rows, asMarkdown))
 	return nil
 }
 
-func batterySummary(ctx *types.Context, nth int, asJSON bool) error {
+func batterySummary(ctx *types.Context, nth int, asJSON bool, asMarkdown bool) (string, error) {
 	summary, err := battery.Get(ctx, nth)
 	if err != nil {
-		return err
+		return "", err
 	}
 	if asJSON {
 		if summary.Count == 0 {
 			result, err := toJSON(map[string]int{"count": 0})
 			if err != nil {
-				return err
+				return "", err
 			}
-			success(ctx, result)
-			return nil
+			return result, nil
 		}
 		result, err := toJSON(summary)
 		if err != nil {
-			return err
+			return "", err
 		}
-		success(ctx, result)
-		return nil
+		return result, nil
 	}
 
 	headers := []string{
@@ -235,6 +298,80 @@ func batterySummary(ctx *types.Context, nth int, asJSON bool) error {
 	} else {
 		rows = append(rows, []string{"count", "0"})
 	}
-	success(ctx, tabular(headers, rows))
+	return tabular(headers, rows, asMarkdown), nil
+}
+
+func envSummary(ctx *types.Context, asJSON bool, asMarkdown bool) error {
+	envMap := make(map[string]any)
+	rows := make([][]string, 0, len(os.Environ()))
+
+	envVars := os.Environ()
+	sort.Strings(envVars)
+
+	for _, entry := range envVars {
+		parts := strings.SplitN(entry, "=", 2)
+		if len(parts) != 2 {
+			continue
+		}
+
+		name, value := parts[0], parts[1]
+
+		if name == path || name == manpath {
+			pathParts := strings.Split(value, ":")
+			if asJSON {
+				envMap[name] = pathParts
+			} else {
+				rows = append(rows, []string{name, strings.Join(pathParts, "\n")})
+			}
+			continue
+		}
+
+		// Handle regular environment variables
+		if asJSON {
+			envMap[name] = value
+		} else {
+			rows = append(rows, []string{name, value})
+		}
+	}
+
+	if asJSON {
+		result, err := toJSON(envMap)
+		if err != nil {
+			return err
+		}
+		success(ctx, result)
+		return nil
+	}
+
+	// Tabular output
+	headers := []string{"Name", "Value"}
+	success(ctx, tabular(headers, rows, asMarkdown))
 	return nil
 }
+
+func getEnv(ctx *types.Context, name string, asJSON bool) (string, error) {
+	value, set := os.LookupEnv(name)
+	ctx.Success = set
+
+	if !asJSON {
+		return value, nil
+	}
+
+	values := []string{}
+
+	switch {
+	case set && (name == path || name == manpath):
+		values = strings.Split(value, ":")
+	case set:
+		values = append(values, value)
+	default:
+		values = nil
+	}
+
+	result, err := toJSON(values)
+	if err != nil {
+		return "", err
+	}
+
+	return result, nil
+}
