@@ -1,4 +1,4 @@
-// package main contains macOS logic
+// Package mac contains macOS logic
 package mac
 
 import (
@@ -6,12 +6,11 @@ import (
 	"os/exec"
 	"strings"
 
+	"github.com/oalders/is/types"
 	"github.com/oalders/is/version"
 )
 
-// TODO: return error when no code name found.
-//
-//nolint:godox
+// CodeName returns the human readable name of a macOS release.
 func CodeName(osVersion string) string {
 	got, err := version.NewVersion(osVersion)
 	if err != nil {
@@ -55,8 +54,8 @@ func CodeName(osVersion string) string {
 	return ""
 }
 
-func Version() (string, error) {
-	o, err := exec.Command("sw_vers", "-productVersion").Output()
+func Version(ctx *types.Context) (string, error) {
+	o, err := exec.CommandContext(ctx.Context, "sw_vers", "-productVersion").Output()
 	if err != nil {
 		return "", fmt.Errorf("could not run sw_vers -productVersion: %w", err)
 	}
