@@ -2,7 +2,6 @@
 package version
 
 import (
-	"errors"
 	"fmt"
 
 	goversion "github.com/hashicorp/go-version"
@@ -12,7 +11,7 @@ func NewVersion(vstring string) (*goversion.Version, error) {
 	// func NewVersion(x string) (string,error) {`
 	got, err := goversion.NewVersion(vstring)
 	if err != nil {
-		err = errors.Join(fmt.Errorf("parse version from \"%s\"", vstring), err)
+		err = fmt.Errorf("parse version from \"%s\": %w", vstring, err)
 	}
 	return got, err
 }
